#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 file-embed
version:              0.0.16.0
visibility:           public
id:                   file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
key:                  file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/file-embed
synopsis:             Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.

category:             Data
abi:                  7a5472838ae5d4f3b529af5558c0b8ac
exposed:              True
exposed-modules:      Data.FileEmbed
import-dirs:          /usr/lib/ghc-9.6.6/site-local/file-embed-0.0.16.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/file-embed-0.0.16.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/file-embed-0.0.16.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-file-embed
hs-libraries:         HSfile-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html:         /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

